@@ -1,4 +1,3 @@
-/* $Xorg: imDefLkup.c,v 1.3 2000/08/17 19:45:12 cpqbld Exp $ */
 /******************************************************************
 
            Copyright 1992, 1993, 1994 by FUJITSU LIMITED
@@ -26,13 +25,11 @@ PERFORMANCE OF THIS SOFTWARE.
                                fujiwara@a80.tech.yk.fujitsu.co.jp
 
 ******************************************************************/
-/* $XFree86: xc/lib/X11/imDefLkup.c,v 3.11 2003/06/23 17:35:43 eich Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 #include <X11/Xatom.h>
-#define  NEED_EVENTS
 #include "Xlibint.h"
 #include "Xlcint.h"
 #include "Ximint.h"
@@ -220,7 +217,7 @@ _XimRespSyncReply(
 	if (IS_FOCUSED(ic))
 	    MARK_NEED_SYNC_REPLY(ic);
 	else
-	    _XimProcSyncReply(ic->core.im, ic);
+	    _XimProcSyncReply((Xim)ic->core.im, ic);
     }
 
     return True;
@@ -893,13 +890,8 @@ _Ximctsconvert(
 }
 
 Public int
-_Ximctstombs(xim, from, from_len, to, to_len, state)
-    XIM		 xim;
-    char	*from;
-    int		 from_len;
-    char	*to;
-    int		 to_len;
-    Status	*state;
+_Ximctstombs(XIM xim, char *from, int from_len,
+	     char *to, int to_len, Status *state)
 {
     return _Ximctsconvert(((Xim)xim)->private.proto.ctom_conv,
 			  from, from_len, to, to_len, state);
